gofuzzexample

package module
v0.0.0-...-c427e28 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 5, 2024 License: MIT Imports: 0 Imported by: 0

README

go-fuzz-example

An example demonstrating how to use my go fuzz actions in CI

Take a look a the workflow definition and a generated issue.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Sum

func Sum(a, b int64) int64

Types

This section is empty.

Directories

Path Synopsis

Jump to